@@ -1,11 +1,11 @@
 #' Historical decomposition for SVAR Models
 #'
-#' Calculation of historical decomposition for an identified SVAR object 'svars' derived by function id.cvm( ),id.cv( ),id.dc( ) or id.ngml( ).
+#' Calculation of historical decomposition for an identified SVAR object 'svars' derived by function id.st( ), id.cvm( ),id.cv( ),id.dc( ) or id.ngml( ).
 #'
 #' @param x SVAR object of class "svars"
 #' @param series Integer, indicating the series that should be decomposed.
 #'
-#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}} or \code{\link{id.cv}}
+#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}}, \code{\link{id.cv} or \code{\link{id.st}}
 #'
 #' @references Kilian, L., Luetkepohl, H., 2017. Structural Vector Autoregressive Analysis, Cambridge University Press.
 #'
@@ -143,9 +143,11 @@ hd <- function(x, series = 1){
   for(i in 3:ncol(yhat)){
     colnames(yhat)[i] <- paste('Cumulative effect of flow ', colnames(y)[i-2], 'shock on ', colnames(y)[series])
   }
-
+  if(inherits(x$y, "ts")){
+  histdecomp <- list(hidec = ts(yhat[, -grep("V1", colnames(yhat))], start = start(lag(x$y, k = -x$p)), end = end(x$y), frequency = frequency(x$y)))
+}else{
   histdecomp <- list(hidec = as.data.frame(yhat))
+}
   class(histdecomp) <- 'hd'
   return(histdecomp)
-
 }
